| Title: | An RKWard plugin for Life Data Analysis and Warranty Prediction using the 'WeibullR' package. |
|---|---|
| Description: | An RKWard plugin for Life Data Analysis and Warranty Prediction using the 'WeibullR' package. |
| Authors: | Alfonso Cano |
| Maintainer: | Alfonso Cano <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.2 |
| Built: | 2026-05-18 19:39:21 UTC |
| Source: | https://github.com/AlfCano/rk.weibull |